@@ -22,11 +22,14 @@ mod use_scrolling;
 mod use_search_param;
 mod use_session_storage;
 mod use_set;
+mod use_size;
+mod use_state_ptr_eq;
 mod use_timeout;
 mod use_title;
 mod use_toggle;
 mod use_unmount;
 mod use_update;
+mod use_web_socket;
 mod use_window_scroll;
 mod use_window_size;
 
@@ -54,10 +57,13 @@ pub use use_scrolling::*;
 pub use use_search_param::*;
 pub use use_session_storage::*;
 pub use use_set::*;
+pub use use_size::*;
+pub use use_state_ptr_eq::*;
 pub use use_timeout::*;
 pub use use_title::*;
 pub use use_toggle::*;
 pub use use_unmount::*;
 pub use use_update::*;
+pub use use_web_socket::*;
 pub use use_window_scroll::*;
 pub use use_window_size::*;
